import{a0 as n,o,Y as d,$ as s,a,S as r}from"./index.c80219e2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="296dae5b-9d5a-4cd2-b627-e7c63e5e6d4e",e._sentryDebugIdIdentifier="sentry-dbid-296dae5b-9d5a-4cd2-b627-e7c63e5e6d4e")}catch{}})();const c={},i={class:"base-layout"},u={class:"base-middle"},_={key:0,class:"base-footer"};function f(e,t){return o(),d("div",i,[s(e.$slots,"sidebar",{},void 0,!0),a("section",u,[s(e.$slots,"navbar",{},void 0,!0),s(e.$slots,"content",{},void 0,!0),e.$slots.footer?(o(),d("section",_,[s(e.$slots,"footer",{},void 0,!0)])):r("",!0)])])}const y=n(c,[["render",f],["__scopeId","data-v-9ad5be20"]]);export{y as B};
//# sourceMappingURL=BaseLayout.457a5ee8.js.map
