import"./App.vue_vue_type_style_index_0_lang.bdad285a.js";import{_ as c}from"./App.vue_vue_type_style_index_0_lang.bdad285a.js";import"./workspaceStore.3e161fa2.js";import"./index.c80219e2.js";import"./url.ceb51a28.js";import"./colorHelpers.96420b31.js";import"./PlayerConfigProvider.da91f318.js";import"./index.9dc0796a.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="06029c37-6210-4885-8b12-ff7d17e64cb0",e._sentryDebugIdIdentifier="sentry-dbid-06029c37-6210-4885-8b12-ff7d17e64cb0")}catch{}})();export{c as default};
//# sourceMappingURL=App.5e7235a1.js.map
