import{_ as n,C as p}from"./View.vue_vue_type_script_setup_true_lang.51cd808a.js";import{d as i,ea as s,o as m,c as a,u as d}from"./index.c80219e2.js";import"./gateway.d74797a6.js";import"./popupNotifcation.da4ba7a0.js";import"./fetch.3bf04551.js";import"./record.6fe21dfd.js";import"./SaveButton.2d5e10c0.js";import"./UnsavedChangesHandler.fabccbde.js";import"./ExclamationCircleOutlined.4e4dbd99.js";import"./CrudView.38cda0b5.js";import"./router.8063dd38.js";import"./Badge.ffab1414.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.ad997955.js";import"./BookOutlined.100d665e.js";import"./url.ceb51a28.js";import"./PhDotsThreeVertical.vue.e90b101d.js";import"./index.a2434e5b.js";import"./index.68a0e349.js";import"./asyncComputed.322c7f8f.js";import"./polling.692abe98.js";import"./PhPencil.vue.00432d1e.js";import"./index.84abaa67.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="313c3931-d8ef-4f03-b9c9-44b4a5de054d",o._sentryDebugIdIdentifier="sentry-dbid-313c3931-d8ef-4f03-b9c9-44b4a5de054d")}catch{}})();const A=i({__name:"EnvVars",setup(o){const e=s().params.projectId,t=new p(e);return(c,f)=>(m(),a(n,{"env-var-repository":d(t),mode:"console"},null,8,["env-var-repository"]))}});export{A as default};
//# sourceMappingURL=EnvVars.71fe4cc4.js.map
