import{O as r}from"./workspaceStore.3e161fa2.js";import{d as i,X as l,o as c,Y as u,b as a,w as n,u as o,aG as s,dd as f,dc as b}from"./index.c80219e2.js";import"./url.ceb51a28.js";import"./colorHelpers.96420b31.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="883a4390-c66b-4e4a-8cd2-f46b17751033",e._sentryDebugIdIdentifier="sentry-dbid-883a4390-c66b-4e4a-8cd2-f46b17751033")}catch{}})();const w=i({__name:"OidcLoginCallback",setup(e){return l(async()=>{await new r().loginCallback()}),(t,d)=>(c(),u("div",null,[a(o(f),null,{default:n(()=>[s("You're authenticated")]),_:1}),a(o(b),null,{default:n(()=>[s(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{w as default};
//# sourceMappingURL=OidcLoginCallback.29671a37.js.map
