import"./index.c80219e2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="4d61a7da-e8ca-4a1a-af56-6dd3e0edaace",e._sentryDebugIdIdentifier="sentry-dbid-4d61a7da-e8ca-4a1a-af56-6dd3e0edaace")}catch{}})();const c=e=>{try{return new URL(e),!0}catch{return!1}},o=(e,a)=>{if(!Object.keys(a).length)return e;const r=new URL(e),t=new URLSearchParams(r.search);return Object.entries(a).forEach(([n,s])=>{r.searchParams.delete(n),t.set(n,s)}),`${r.origin}${r.pathname}?${t.toString()}`};export{c as i,o as m};
//# sourceMappingURL=url.ceb51a28.js.map
