import{d as a,o,Y as s,b as c,u as d,by as r,a0 as _}from"./index.c80219e2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="d220f488-7892-44e0-a33c-74cc9a93cc60",e._sentryDebugIdIdentifier="sentry-dbid-d220f488-7892-44e0-a33c-74cc9a93cc60")}catch{}})();const i={class:"centered"},f=a({__name:"LoadingContainer",setup(e){return(n,t)=>(o(),s("div",i,[c(d(r))]))}});const u=_(f,[["__scopeId","data-v-52e6209a"]]);export{u as L};
//# sourceMappingURL=LoadingContainer.015adcb5.js.map
