import{O as l}from"./index.c80219e2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="3a9c9193-fc3b-4f7d-94fe-e7eddbf5d46e",e._sentryDebugIdIdentifier="sentry-dbid-3a9c9193-fc3b-4f7d-94fe-e7eddbf5d46e")}catch{}})();function d(e){return l.string().email().safeParse(e).success}function u(e){return e.charAt(0).toUpperCase()+e.slice(1)}function g(e,n,r=!1,t=!0,a=!1){const c=(t?e.toLocaleLowerCase():e).normalize("NFD").replace(/[\u0300-\u036f]/g,""),s=a?c.replace(/[^a-zA-Z0-9/]/g,"_"):c.replace(/[^a-zA-Z0-9]/g,"_"),i=r?s:s.replace(/_+/g,"_");return n?i:i.replace(/_$/,"")}function p(e){var o;const r=e.toLocaleLowerCase().trim().normalize("NFD").replace(/[\u0300-\u036f]/g,""),t=/[a-z0-9]+/g,a=r.match(t);return(o=a==null?void 0:a.join("-"))!=null?o:""}export{p as a,u as c,d as i,g as n};
//# sourceMappingURL=string.1ce9e791.js.map
