import{R as d,f as l}from"./index.c80219e2.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[e]="3737f74f-6f30-4701-889e-0f05b9c6ab51",r._sentryDebugIdIdentifier="sentry-dbid-3737f74f-6f30-4701-889e-0f05b9c6ab51")}catch{}})();const i=r=>{const e=d({loading:!0,result:null,error:null}),n=t=>(e.value={loading:!1,result:t,error:null},t),s=t=>{e.value={loading:!1,result:null,error:t}},o=async()=>(e.value={loading:!0,result:e.value.result,error:null},r().then(n).catch(s));o();const u=l(()=>e.value.loading),a=l(()=>e.value.result),f=l(()=>e.value.error);return{loading:u,result:a,error:f,refetch:o}};export{i as a};
//# sourceMappingURL=asyncComputed.322c7f8f.js.map
