import{d as n,o as s,Y as d,a,$ as f,ed as r,a0 as l}from"./index.c80219e2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="47522607-3fff-4de9-8e91-09c836b8ffc2",e._sentryDebugIdIdentifier="sentry-dbid-47522607-3fff-4de9-8e91-09c836b8ffc2")}catch{}})();const c={class:"content-layout"},_=n({__name:"ContentLayout",props:{fullWidth:{type:Boolean}},setup(e){return(t,o)=>(s(),d("div",c,[a("div",{class:r(["centered-layout",{"full-width":t.fullWidth}])},[f(t.$slots,"default",{},void 0,!0)],2)]))}});const i=l(_,[["__scopeId","data-v-6397d501"]]);export{i as C};
//# sourceMappingURL=ContentLayout.8c42122d.js.map
