import{_ as l}from"./Login.vue_vue_type_script_setup_true_lang.28a20c7f.js";import{d as m,eo as b,ea as f,o as g,Y as y,b as w,u as n,a0 as k}from"./index.c80219e2.js";import{u as h}from"./workspaceStore.3e161fa2.js";import"./Logo.5097442c.js";import"./string.1ce9e791.js";import"./OTPInput.ecdd385f.js";import"./index.84abaa67.js";import"./url.ceb51a28.js";import"./colorHelpers.96420b31.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="a85286cd-035b-4dbc-88b2-4675a4b0d84e",e._sentryDebugIdIdentifier="sentry-dbid-a85286cd-035b-4dbc-88b2-4675a4b0d84e")}catch{}})();const v={class:"runner"},I=m({__name:"Login",setup(e){const o=b(),t=f(),a=h(),_=async()=>{const{redirect:r,...s}=t.query;if(r){await o.push({path:r,query:s,params:t.params});return}o.push({name:"playerHome",query:s})};return(r,s)=>{var c,d,u,p,i;return g(),y("div",v,[w(l,{"logo-url":(d=(c=n(a).state.workspace)==null?void 0:c.logoUrl)!=null?d:void 0,"brand-name":(u=n(a).state.workspace)==null?void 0:u.brandName,locale:(i=(p=n(a).state.workspace)==null?void 0:p.language)!=null?i:"en",onDone:_},null,8,["logo-url","brand-name","locale"])])}}});const C=k(I,[["__scopeId","data-v-cb33c596"]]);export{C as default};
//# sourceMappingURL=Login.efe1165c.js.map
