import{P as m}from"./PlayerNavbar.213fcfd6.js";import{d as b,eo as g,ea as i,e as h,f as y,r as k,o as c,Y as v,u as a,c as w,S as L,a as C,b as I,a0 as N}from"./index.c80219e2.js";import{u as V}from"./workspaceStore.3e161fa2.js";import"./metadata.13452202.js";import"./PhRobot.vue.1294b24e.js";import"./PhWebhooksLogo.vue.2bc7807a.js";import"./LoadingOutlined.9ae79bc2.js";import"./PhSignOut.vue.9e455164.js";import"./index.cfa826cc.js";import"./Avatar.f00fa1cc.js";import"./url.ceb51a28.js";import"./colorHelpers.96420b31.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="bc33f715-fbf1-4566-bbd0-843406bbf212",o._sentryDebugIdIdentifier="sentry-dbid-bc33f715-fbf1-4566-bbd0-843406bbf212")}catch{}})();const x={class:"main-container"},B={class:"content"},D=b({__name:"Main",setup(o){const e=g(),t=V(),u=i().path,n=h(null),d=async({path:r,id:s})=>{n.value=s,await e.push({path:`/${r}`}),n.value=null},l=()=>{e.push({name:"playerLogin"})},p=()=>{e.push({name:"playerLogin"})},_=y(()=>!!i().meta.hideLogin);return(r,s)=>{const f=k("RouterView");return c(),v("div",x,[a(t).state.workspace?(c(),w(m,{key:0,"current-path":a(u),"hide-login":_.value,"runner-data":a(t).state.workspace,loading:n.value,onNavigate:d,onLoginClick:p,onLogoutClick:l},null,8,["current-path","hide-login","runner-data","loading"])):L("",!0),C("section",B,[I(f)])])}}});const F=N(D,[["__scopeId","data-v-f095bece"]]);export{F as default};
//# sourceMappingURL=Main.5aa5aa72.js.map
