import{U as s,dA as c,dB as i}from"./index.c80219e2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="673bd60b-7ede-40bb-9a70-d56403ca3653",e._sentryDebugIdIdentifier="sentry-dbid-673bd60b-7ede-40bb-9a70-d56403ca3653")}catch{}})();const{DatePicker:n,WeekPicker:t,MonthPicker:r,YearPicker:b,TimePicker:m,QuarterPicker:a,RangePicker:o}=c(i),u=s(n,{WeekPicker:t,MonthPicker:r,YearPicker:b,RangePicker:o,TimePicker:m,QuarterPicker:a,install:e=>(e.component(n.name,n),e.component(o.name,o),e.component(r.name,r),e.component(t.name,t),e.component(a.name,a),e)});export{u as D,r as M,a as Q,o as R,t as W};
//# sourceMappingURL=dayjs.38e06176.js.map
