import{k as a,T as n,m as r,P as o,C as d,M as p,s as c,n as s,p as f,q as m,t as u,v as g}from"./index.c80219e2.js";import{s as y,c as l,a as i}from"./workspaceStore.3e161fa2.js";import{_ as b}from"./App.vue_vue_type_style_index_0_lang.bdad285a.js";import"./url.ceb51a28.js";import"./colorHelpers.96420b31.js";import"./PlayerConfigProvider.da91f318.js";import"./index.9dc0796a.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="1ffd6dd5-1af3-41d6-a507-d6c6ede5bfc9",t._sentryDebugIdIdentifier="sentry-dbid-1ffd6dd5-1af3-41d6-a507-d6c6ede5bfc9")}catch{}})();class w{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await y();const t=l(),e=a({render:()=>f(b)});n.init(),r(e,i),w.init(),e.use(i),e.use(t),e.use(o),e.mount("#app"),e.component("VSelect",d),e.component("Markdown",p),e.component("Message",c),s(e,m),s(e,u),s(e,g)})();
//# sourceMappingURL=player.bb464093.js.map
