import{d as i,o as p,c as n,w as a,b as m,u as t}from"./index.c80219e2.js";import"./linters.ac1440dd.js";import{W as s}from"./workspaces.bde02983.js";import{C as d}from"./ContentLayout.8c42122d.js";import{_ as f,E as c}from"./View.vue_vue_type_script_setup_true_lang.51cd808a.js";import"./asyncComputed.322c7f8f.js";import"./workspaceStore.3e161fa2.js";import"./url.ceb51a28.js";import"./colorHelpers.96420b31.js";import"./record.6fe21dfd.js";import"./gateway.d74797a6.js";import"./popupNotifcation.da4ba7a0.js";import"./fetch.3bf04551.js";import"./SaveButton.2d5e10c0.js";import"./UnsavedChangesHandler.fabccbde.js";import"./ExclamationCircleOutlined.4e4dbd99.js";import"./CrudView.38cda0b5.js";import"./router.8063dd38.js";import"./Badge.ffab1414.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.ad997955.js";import"./BookOutlined.100d665e.js";import"./PhDotsThreeVertical.vue.e90b101d.js";import"./index.a2434e5b.js";import"./index.68a0e349.js";import"./polling.692abe98.js";import"./PhPencil.vue.00432d1e.js";import"./index.84abaa67.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="d8501607-74f9-49e3-a1ca-0f37eb05d2ac",o._sentryDebugIdIdentifier="sentry-dbid-d8501607-74f9-49e3-a1ca-0f37eb05d2ac")}catch{}})();const G=i({__name:"EnvVarsEditor",setup(o){const r=new c;return(e,u)=>(p(),n(d,null,{default:a(()=>[m(f,{"env-var-repository":t(r),mode:"editor","file-opener":t(s)},null,8,["env-var-repository","file-opener"])]),_:1}))}});export{G as default};
//# sourceMappingURL=EnvVarsEditor.bb4719e9.js.map
