import{_ as n}from"./TasksView.vue_vue_type_script_setup_true_lang.dd1275a7.js";import{L as i}from"./tasksController.ffa852fb.js";import{d as p,o as d,c,w as a,b as o,aG as _,u as s,dd as f,a0 as m}from"./index.c80219e2.js";import{C as l}from"./ContentLayout.8c42122d.js";import"./metadata.13452202.js";import"./PhRobot.vue.1294b24e.js";import"./PhWebhooksLogo.vue.2bc7807a.js";import"./ant-design.a9be0f0e.js";import"./string.1ce9e791.js";import"./dayjs.38e06176.js";import"./index.a2434e5b.js";import"./gateway.d74797a6.js";import"./popupNotifcation.da4ba7a0.js";import"./scripts.32a6a4e4.js";import"./record.6fe21dfd.js";import"./linters.ac1440dd.js";import"./asyncComputed.322c7f8f.js";import"./polling.692abe98.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="f5bcd6a4-5015-4654-a0b3-34af8fd99b86",t._sentryDebugIdIdentifier="sentry-dbid-f5bcd6a4-5015-4654-a0b3-34af8fd99b86")}catch{}})();const u=p({__name:"Tasks",setup(t){const e=new i;return(r,b)=>(d(),c(l,null,{default:a(()=>[o(s(f),null,{default:a(()=>[_("Tasks")]),_:1}),o(n,{class:"tasks",api:s(e),stages:null,editor:""},null,8,["api"])]),_:1}))}});const R=m(u,[["__scopeId","data-v-10aa4cc9"]]);export{R as default};
//# sourceMappingURL=Tasks.79a51f77.js.map
