import{O as r}from"./workspaceStore.3e161fa2.js";import{d as l,X as i,o as u,Y as c,b as a,w as o,u as n,aG as s,dd as f,dc as b}from"./index.c80219e2.js";import"./url.ceb51a28.js";import"./colorHelpers.96420b31.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="a8fb65ef-ee73-456f-9833-50028db3c403",e._sentryDebugIdIdentifier="sentry-dbid-a8fb65ef-ee73-456f-9833-50028db3c403")}catch{}})();const w=l({__name:"OidcLogoutCallback",setup(e){return i(async()=>{await new r().logoutCallback()}),(t,d)=>(u(),c("div",null,[a(n(f),null,{default:o(()=>[s("You're authenticated")]),_:1}),a(n(b),null,{default:o(()=>[s(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{w as default};
//# sourceMappingURL=OidcLogoutCallback.e2929384.js.map
