import{L as t}from"./Logo.5097442c.js";import{d as a,o as n,c as r,u as d}from"./index.c80219e2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="66db3f3d-4f57-488a-976f-efdab923f5f9",e._sentryDebugIdIdentifier="sentry-dbid-66db3f3d-4f57-488a-976f-efdab923f5f9")}catch{}})();const f="/assets/logo.0faadfa2.svg",b=a({__name:"AbstraLogo",props:{hideText:{type:Boolean},size:{}},setup(e){return(o,s)=>(n(),r(t,{"image-url":d(f),"brand-name":"Abstra","hide-text":o.hideText,size:o.size},null,8,["image-url","hide-text","size"]))}});export{b as _};
//# sourceMappingURL=AbstraLogo.vue_vue_type_script_setup_true_lang.a62ecfda.js.map
